flutter_inappwebview_ios library
Classes
- IOSChromeSafariBrowser
- Class that provides a visible standard interface for browsing the web. It presents a self-contained web interface inside your app.
- IOSChromeSafariBrowserCreationParams
- Object specifying creation parameters for creating a IOSChromeSafariBrowser.
- IOSCookieManager
- Class that implements a singleton object (shared instance) which manages the cookies used by WebView instances.
- IOSCookieManagerCreationParams
- Object specifying creation parameters for creating a IOSCookieManager.
- IOSFindInteractionController
-
This class represents the controller used by the
WebViewto add text-finding capabilities, such as the "Find on page" feature. - IOSFindInteractionControllerCreationParams
- Object specifying creation parameters for creating a IOSFindInteractionController.
- IOSHeadlessInAppWebView
-
Class that represents a WebView in headless mode.
It can be used to run a WebView in background without attaching an
InAppWebViewto the widget tree. - IOSHeadlessInAppWebViewCreationParams
- Object specifying creation parameters for creating a IOSHeadlessInAppWebView.
- IOSHttpAuthCredentialDatabase
- Class that implements a singleton object (shared instance) which manages the shared HTTP auth credentials cache.
- IOSHttpAuthCredentialDatabaseCreationParams
- Object specifying creation parameters for creating a IOSHttpAuthCredentialDatabase.
- IOSInAppBrowser
-
This class represents a native WebView displayed on top of the Flutter App,
so it's not integrated into the Flutter widget tree.
It uses the native WebView of the platform.
The webViewController field can be used to access the
PlatformInAppWebViewControllerAPI. - IOSInAppBrowserCreationParams
- Object specifying creation parameters for creating a IOSInAppBrowser.
- IOSInAppWebViewController
-
Controls a WebView, such as an
InAppWebViewwidget instance, a IOSHeadlessInAppWebView instance or IOSInAppBrowser WebView instance. - IOSInAppWebViewControllerCreationParams
- Object specifying creation parameters for creating a IOSInAppWebViewController.
- IOSInAppWebViewPlatform
-
Implementation of
InAppWebViewPlatformusing the WebKit API. - IOSInAppWebViewWidget
- Flutter Widget for adding an inline native WebView integrated in the flutter widget tree.
- IOSInAppWebViewWidgetCreationParams
-
Object specifying creation parameters for creating a
PlatformInAppWebViewWidget. - IOSJavaScriptReplyProxy
- IOSJavaScriptReplyProxyCreationParams
- Object specifying creation parameters for creating a IOSJavaScriptReplyProxy.
- IOSLocalStorage
-
Class that provides methods to manage the JavaScript
window.localStorageobject. It used byPlatformWebStorage. - IOSLocalStorageCreationParams
- Object specifying creation parameters for creating a IOSLocalStorage.
- IOSPrintJobController
-
Class representing a print job eventually returned by
PlatformInAppWebViewController.printCurrentPage. - IOSPrintJobControllerCreationParams
- Object specifying creation parameters for creating a IOSPrintJobController.
- IOSPullToRefreshController
- A standard controller that can initiate the refreshing of a scroll view’s contents. This should be used whenever the user can refresh the contents of a WebView via a vertical swipe gesture.
- IOSPullToRefreshControllerCreationParams
- Object specifying creation parameters for creating a IOSPullToRefreshController.
- IOSSessionStorage
-
Class that provides methods to manage the JavaScript
window.sessionStorageobject. It used byPlatformWebStorage. - IOSSessionStorageCreationParams
- Object specifying creation parameters for creating a IOSSessionStorage.
- IOSStorage
-
Class that provides methods to manage the JavaScript Storage object.
It is used by
PlatformLocalStorageandPlatformSessionStorage. - IOSStorageCreationParams
- Object specifying creation parameters for creating a IOSStorage.
- IOSWebAuthenticationSession
- A session that an app uses to authenticate a user through a web service.
- IOSWebAuthenticationSessionCreationParams
- Object specifying creation parameters for creating a IOSWebAuthenticationSession.
- IOSWebMessageChannel
- The representation of the HTML5 message channels.
- IOSWebMessageChannelCreationParams
- Object specifying creation parameters for creating a IOSWebMessageChannel.
- IOSWebMessageListener
-
This listener receives messages sent on the JavaScript object which was injected by
PlatformInAppWebViewController.addWebMessageListener. - IOSWebMessageListenerCreationParams
- Object specifying creation parameters for creating a IOSWebMessageListener.
- IOSWebMessagePort
- The representation of the HTML5 message ports.
- IOSWebMessagePortCreationParams
- Object specifying creation parameters for creating a IOSWebMessagePort.
- IOSWebStorage
-
Class that provides access to the JavaScript Web Storage API:
window.sessionStorageandwindow.localStorage. It used byPlatformInAppWebViewController.webStorage. - IOSWebStorageCreationParams
- Object specifying creation parameters for creating a IOSWebStorage.
- IOSWebStorageManager
- Class that implements a singleton object (shared instance) which manages the web storage used by WebView instances.
- IOSWebStorageManagerCreationParams
- Object specifying creation parameters for creating a IOSWebStorageManager.