IOSInAppBrowser class

This class represents a native WebView displayed on top of the Flutter App, so it's not integrated into the Flutter widget tree. It uses the native WebView of the platform. The webViewController field can be used to access the PlatformInAppWebViewController API.

Inheritance
  • Object
  • PlatformInterface
  • IOSInAppBrowser

Constructors

IOSInAppBrowser(PlatformInAppBrowserCreationParams params)
Constructs a IOSInAppBrowser.
IOSInAppBrowser.static()
Provide static access.
factory

Properties

contextMenu → ContextMenu?
Context menu which contains custom menu items to be shown when ContextMenu is presented.
no setter
eventHandler ↔ PlatformInAppBrowserEvents?
Event handler object that handles the PlatformInAppBrowser events.
getter/setter pairinherited
findInteractionController → PlatformFindInteractionController?
Represents the find interaction feature controller.
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
id → String
View ID used internally.
final
initialUserScripts → UnmodifiableListView<UserScript>?
Initial list of user scripts to be loaded at start or end of a page loading. To add or remove user scripts, you have to use the InAppWebViewController's methods such as InAppWebViewController.addUserScript, InAppWebViewController.removeUserScript, InAppWebViewController.removeAllUserScripts, etc.
no setterinherited
params → PlatformInAppBrowserCreationParams
The parameters used to initialize the PlatformInAppBrowser.
finalinherited
pullToRefreshController → PlatformPullToRefreshController?
Represents the pull-to-refresh feature controller.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webViewController → IOSInAppWebViewController?
WebView Controller that can be used to access the PlatformInAppWebViewController API. When onExit is fired, this will be null and cannot be used anymore.
no setter
webViewEnvironment → PlatformWebViewEnvironment?
Used to create the PlatformInAppBrowser using the specified environment.
no setterinherited
windowId → int?
The window id of a CreateWindowAction.windowId.
no setterinherited

Methods

addMenuItem(InAppBrowserMenuItem menuItem) → void
Adds a InAppBrowserMenuItem to the menu. If the browser is already open, it will take effect the next time it is opened.
addMenuItems(List<InAppBrowserMenuItem> menuItems) → void
Adds a list of InAppBrowserMenuItem to the menu. If the browser is already open, it will take effect the next time it is opened.
close() → Future<void>
Closes the PlatformInAppBrowser window.
dispose() → void
Disposes the channel and controllers.
getOptions() → Future<InAppBrowserClassOptions?>
Use getSettings instead.
getSettings() → Future<InAppBrowserClassSettings?>
Gets the current PlatformInAppBrowser settings. Returns null if it wasn't able to get them.
hasMenuItem(InAppBrowserMenuItem menuItem) → bool
Returns true if the menuItem has been already added, otherwise false.
hide() → Future<void>
Hides the PlatformInAppBrowser window. Calling this has no effect if the PlatformInAppBrowser was already hidden.
isClassSupported({TargetPlatform? platform}) → bool
Check if the current class is supported by the defaultTargetPlatform or a specific platform.
inherited
isEventMethodSupported(PlatformInAppBrowserEventsMethod method, {TargetPlatform? platform}) → bool
Check if the given method is supported by the defaultTargetPlatform or a specific platform.
inherited
isHidden() → Future<bool>
Check if the Web View of the PlatformInAppBrowser instance is hidden.
isMethodSupported(PlatformInAppBrowserMethod method, {TargetPlatform? platform}) → bool
Check if the given method is supported by the defaultTargetPlatform or a specific platform.
inherited
isOpened() → bool
Returns true if the PlatformInAppBrowser instance is opened, otherwise false.
isPropertySupported(PlatformInAppBrowserProperty property, {TargetPlatform? platform}) → bool
Check if the given property is supported by the defaultTargetPlatform or a specific platform.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
openData({required String data, String mimeType = "text/html", String encoding = "utf8", WebUri? baseUrl, Uri? androidHistoryUrl, WebUri? historyUrl, InAppBrowserClassOptions? options, InAppBrowserClassSettings? settings}) → Future<void>
Opens the PlatformInAppBrowser instance with data as a content, using baseUrl as the base URL for it.
openFile({required String assetFilePath, InAppBrowserClassOptions? options, InAppBrowserClassSettings? settings}) → Future<void>
Opens the PlatformInAppBrowser instance with the given assetFilePath file.
openUrlRequest({required URLRequest urlRequest, InAppBrowserClassOptions? options, InAppBrowserClassSettings? settings}) → Future<void>
Opens the PlatformInAppBrowser instance with an urlRequest.
openWithSystemBrowser({required WebUri url}) → Future<void>
This is a static method that opens an url in the system browser. You wont be able to use the PlatformInAppBrowser events and methods here.
removeAllMenuItem() → void
Removes all the menu items from the list. If the browser is already open, it will take effect the next time it is opened.
removeMenuItem(InAppBrowserMenuItem menuItem) → bool
Removes the menuItem from the list. Returns true if it was in the list, false otherwise. If the browser is already open, it will take effect the next time it is opened.
removeMenuItems(List<InAppBrowserMenuItem> menuItems) → void
Removes a list of menuItems from the list. If the browser is already open, it will take effect the next time it is opened.
setOptions({required InAppBrowserClassOptions options}) → Future<void>
Use setSettings instead.
setSettings({required InAppBrowserClassSettings settings}) → Future<void>
Sets the PlatformInAppBrowser settings with the new settings and evaluates them.
show() → Future<void>
Displays a PlatformInAppBrowser window that was opened hidden. Calling this has no effect if the PlatformInAppBrowser was already visible.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited