IOSInAppWebViewControllerCreationParams class

Object specifying creation parameters for creating a IOSInAppWebViewController.

When adding additional fields make sure they can be null or have a default value to avoid breaking changes. See PlatformInAppWebViewControllerCreationParams for more information.

Annotations

Constructors

IOSInAppWebViewControllerCreationParams({required dynamic id, PlatformWebViewCreationParams? webviewParams})
Creates a new IOSInAppWebViewControllerCreationParams instance.
const
IOSInAppWebViewControllerCreationParams.fromPlatformInAppWebViewControllerCreationParams(PlatformInAppWebViewControllerCreationParams params)
Creates a IOSInAppWebViewControllerCreationParams instance based on PlatformInAppWebViewControllerCreationParams.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → dynamic
WebView ID.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webviewParams → PlatformWebViewCreationParams?
WebView params.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited